Liferay.Loader.define('@questions-web$apollo/client@3.0.0-beta.50/cache/inmemory/readFromStore', ['module', 'exports', 'require'], function (module, exports, require) {
    var define = undefined;
    var global = window;
    {
        import { __assign } from 'tslib';
        import { InvariantError, invariant } from 'ts-invariant';
        import { createFragmentMap } from '../../utilities/graphql/fragments.js';
        import { isReference, makeReference, isField, resultKeyNameFromField, isInlineFragment } from '../../utilities/graphql/storeUtils.js';
        import { getDefaultValues, getQueryDefinition, getMainDefinition, getFragmentDefinitions } from '../../utilities/graphql/getFromAST.js';
        import { shouldInclude } from '../../utilities/graphql/directives.js';
        import { addTypenameToDocument } from '../../utilities/graphql/transform.js';
        import { mergeDeepArray } from '../../utilities/common/mergeDeep.js';
        import { wrap } from 'optimism';
        import { MissingFieldError } from '../core/types/common.js';
        import { maybeDeepFreeze } from '../../utilities/common/maybeDeepFreeze.js';
        import { getTypenameFromStoreObject } from './helpers.js';
        import { supportsResultCaching } from './entityStore.js';

        function missingFromInvariant(err, context) {
            return new MissingFieldError(err.message, context.path.slice(), context.query, context.variables);
        }
        var StoreReader = function () {
            function StoreReader(config) {
                var _this = this;
                this.config = config;
                this.executeSelectionSet = wrap(function (options) {
                    return _this.execSelectionSetImpl(options);
                }, {
                    keyArgs: function (options) {
                        return [options.context.store, options.selectionSet, options.objectOrReference, options.context.varString];
                    },
                    makeCacheKey: function (store, selectionSet, parent, varString) {
                        if (supportsResultCaching(store)) {
                            return store.makeCacheKey(selectionSet, isReference(parent) ? parent.__ref : parent, varString);
                        }
                    }
                });
                this.knownResults = new WeakMap();
                this.executeSubSelectedArray = wrap(function (options) {
                    return _this.execSubSelectedArrayImpl(options);
                }, {
                    makeCacheKey: function (_a) {
                        var field = _a.field,
                            array = _a.array,
                            context = _a.context;
                        if (supportsResultCaching(context.store)) {
                            return context.store.makeCacheKey(field, array, context.varString);
                        }
                    }
                });
                this.config = __assign({ addTypename: true }, config);
            }
            StoreReader.prototype.readQueryFromStore = function (options) {
                return this.diffQueryAgainstStore(__assign(__assign({}, options), { returnPartialData: false })).result;
            };
            StoreReader.prototype.diffQueryAgainstStore = function (_a) {
                var store = _a.store,
                    query = _a.query,
                    _b = _a.rootId,
                    rootId = _b === void 0 ? 'ROOT_QUERY' : _b,
                    variables = _a.variables,
                    _c = _a.returnPartialData,
                    returnPartialData = _c === void 0 ? true : _c;
                var policies = this.config.policies;
                variables = __assign(__assign({}, getDefaultValues(getQueryDefinition(query))), variables);
                var execResult = this.executeSelectionSet({
                    selectionSet: getMainDefinition(query).selectionSet,
                    objectOrReference: makeReference(rootId),
                    context: {
                        store: store,
                        query: query,
                        policies: policies,
                        variables: variables,
                        varString: JSON.stringify(variables),
                        fragmentMap: createFragmentMap(getFragmentDefinitions(query)),
                        toReference: store.toReference,
                        getFieldValue: store.getFieldValue,
                        path: []
                    }
                });
                var hasMissingFields = execResult.missing && execResult.missing.length > 0;
                if (hasMissingFields && !returnPartialData) {
                    throw execResult.missing[0];
                }
                return {
                    result: execResult.result,
                    missing: execResult.missing,
                    complete: !hasMissingFields
                };
            };
            StoreReader.prototype.isFresh = function (result, store, parent, selectionSet, varString) {
                if (supportsResultCaching(store) && this.knownResults.get(result) === selectionSet) {
                    var latest = this.executeSelectionSet.peek(store, selectionSet, parent, varString);
                    if (latest && result === latest.result) {
                        return true;
                    }
                }
                return false;
            };
            StoreReader.prototype.execSelectionSetImpl = function (_a) {
                var _this = this;
                var selectionSet = _a.selectionSet,
                    objectOrReference = _a.objectOrReference,
                    context = _a.context;
                if (isReference(objectOrReference) && !context.policies.rootTypenamesById[objectOrReference.__ref] && !context.store.has(objectOrReference.__ref)) {
                    return {
                        result: {},
                        missing: [missingFromInvariant(new InvariantError(46), context)]
                    };
                }
                var fragmentMap = context.fragmentMap,
                    variables = context.variables,
                    policies = context.policies,
                    store = context.store;
                var objectsToMerge = [];
                var finalResult = { result: null };
                var typename = store.getFieldValue(objectOrReference, "__typename");
                if (this.config.addTypename && typeof typename === "string" && !policies.rootIdsByTypename[typename]) {
                    objectsToMerge.push({ __typename: typename });
                }
                function getMissing() {
                    return finalResult.missing || (finalResult.missing = []);
                }
                function handleMissing(result) {
                    var _a;
                    if (result.missing) (_a = getMissing()).push.apply(_a, result.missing);
                    return result.result;
                }
                var workSet = new Set(selectionSet.selections);
                workSet.forEach(function (selection) {
                    var _a;
                    if (!shouldInclude(selection, variables)) return;
                    if (isField(selection)) {
                        var fieldValue = policies.readField({
                            fieldName: selection.name.value,
                            field: selection,
                            variables: context.variables,
                            from: objectOrReference
                        }, context);
                        var resultName = resultKeyNameFromField(selection);
                        context.path.push(resultName);
                        if (fieldValue === void 0) {
                            if (!addTypenameToDocument.added(selection)) {
                                getMissing().push(missingFromInvariant(new InvariantError(47), context));
                            }
                        } else if (Array.isArray(fieldValue)) {
                            fieldValue = handleMissing(_this.executeSubSelectedArray({
                                field: selection,
                                array: fieldValue,
                                context: context
                            }));
                        } else if (!selection.selectionSet) {} else if (fieldValue != null) {
                            fieldValue = handleMissing(_this.executeSelectionSet({
                                selectionSet: selection.selectionSet,
                                objectOrReference: fieldValue,
                                context: context
                            }));
                        }
                        if (fieldValue !== void 0) {
                            objectsToMerge.push((_a = {}, _a[resultName] = fieldValue, _a));
                        }
                        invariant(context.path.pop() === resultName);
                    } else {
                        var fragment = void 0;
                        if (isInlineFragment(selection)) {
                            fragment = selection;
                        } else {
                            invariant(fragment = fragmentMap[selection.name.value], 48);
                        }
                        if (policies.fragmentMatches(fragment, typename)) {
                            fragment.selectionSet.selections.forEach(workSet.add, workSet);
                        }
                    }
                });
                finalResult.result = mergeDeepArray(objectsToMerge);

                this.knownResults.set(finalResult.result, selectionSet);
                return finalResult;
            };
            StoreReader.prototype.execSubSelectedArrayImpl = function (_a) {
                var _this = this;
                var field = _a.field,
                    array = _a.array,
                    context = _a.context;
                var missing;
                function handleMissing(childResult, i) {
                    if (childResult.missing) {
                        missing = missing || [];
                        missing.push.apply(missing, childResult.missing);
                    }
                    invariant(context.path.pop() === i);
                    return childResult.result;
                }
                array = array.map(function (item, i) {
                    if (item === null) {
                        return null;
                    }
                    context.path.push(i);
                    if (Array.isArray(item)) {
                        return handleMissing(_this.executeSubSelectedArray({
                            field: field,
                            array: item,
                            context: context
                        }), i);
                    }
                    if (field.selectionSet) {
                        return handleMissing(_this.executeSelectionSet({
                            selectionSet: field.selectionSet,
                            objectOrReference: item,
                            context: context
                        }), i);
                    }

                    invariant(context.path.pop() === i);
                    return item;
                });

                return { result: array, missing: missing };
            };
            return StoreReader;
        }();
        function assertSelectionSetForIdValue(store, field, fieldValue) {
            if (!field.selectionSet) {
                var workSet_1 = new Set([fieldValue]);
                workSet_1.forEach(function (value) {
                    if (value && typeof value === "object") {
                        invariant(!isReference(value), 49);
                        Object.values(value).forEach(workSet_1.add, workSet_1);
                    }
                });
            }
        }

        export { StoreReader };
        //# sourceMappingURL=readFromStore.js.map
    }
});
//# sourceMappingURL=readFromStore.js.map