Liferay.Loader.define('@questions-web$apollo/client@3.0.0-beta.50/core/QueryInfo', ['module', 'exports', 'require'], function (module, exports, require) {
    var define = undefined;
    var global = window;
    {
        import { equal } from '@wry/equality';
        import { graphQLResultHasError } from '../utilities/common/errorHandling.js';
        import { isNonEmptyArray } from '../utilities/common/arrays.js';
        import { NetworkStatus, isNetworkRequestInFlight } from './networkStatus.js';

        var QueryInfo = function () {
            function QueryInfo(cache) {
                this.cache = cache;
                this.listeners = new Set();
                this.document = null;
                this.lastRequestId = 1;
                this.subscriptions = new Set();
                this.dirty = false;
                this.diff = null;
                this.observableQuery = null;
            }
            QueryInfo.prototype.init = function (query) {
                var networkStatus = query.networkStatus || NetworkStatus.loading;
                if (this.variables && this.networkStatus !== NetworkStatus.loading && !equal(this.variables, query.variables)) {
                    networkStatus = NetworkStatus.setVariables;
                }
                Object.assign(this, {
                    document: query.document,
                    variables: query.variables,
                    networkError: null,
                    graphQLErrors: this.graphQLErrors || [],
                    networkStatus: networkStatus
                });
                if (query.observableQuery) {
                    this.setObservableQuery(query.observableQuery);
                }
                if (query.lastRequestId) {
                    this.lastRequestId = query.lastRequestId;
                }
                return this;
            };
            QueryInfo.prototype.setDirty = function () {
                var _this = this;
                if (!this.dirty) {
                    this.dirty = true;
                    if (!this.notifyTimeout) {
                        this.notifyTimeout = setTimeout(function () {
                            return _this.notify();
                        }, 0);
                    }
                }
                return this;
            };
            QueryInfo.prototype.setDiff = function (diff) {
                var oldDiff = this.diff;
                this.diff = diff;
                if (!this.dirty && (diff === null || diff === void 0 ? void 0 : diff.result) !== (oldDiff === null || oldDiff === void 0 ? void 0 : oldDiff.result)) {
                    this.setDirty();
                }
            };
            QueryInfo.prototype.setObservableQuery = function (oq) {
                if (oq === this.observableQuery) return;
                if (this.oqListener) {
                    this.listeners.delete(this.oqListener);
                }
                this.observableQuery = oq;
                if (oq) {
                    this.listeners.add(this.oqListener = function () {
                        return oq.reobserve();
                    });
                } else {
                    delete this.oqListener;
                }
            };
            QueryInfo.prototype.notify = function () {
                var _this = this;
                if (this.notifyTimeout) {
                    clearTimeout(this.notifyTimeout);
                    this.notifyTimeout = void 0;
                }
                if (this.shouldNotify()) {
                    this.listeners.forEach(function (listener) {
                        return listener(_this);
                    });
                }
                this.dirty = false;
            };
            QueryInfo.prototype.shouldNotify = function () {
                if (!this.dirty || !this.listeners.size) {
                    return false;
                }
                if (isNetworkRequestInFlight(this.networkStatus) && this.observableQuery) {
                    var fetchPolicy = this.observableQuery.options.fetchPolicy;
                    if (fetchPolicy !== "cache-only" && fetchPolicy !== "cache-and-network") {
                        return false;
                    }
                }
                return true;
            };
            QueryInfo.prototype.stop = function () {
                this.cancel();
                delete this.cancel;
                this.variables = this.networkStatus = this.networkError = this.graphQLErrors = void 0;
                var oq = this.observableQuery;
                if (oq) oq.stopPolling();
            };
            QueryInfo.prototype.cancel = function () {};
            QueryInfo.prototype.updateWatch = function (variables) {
                var _this = this;
                if (!this.lastWatch || this.lastWatch.query !== this.document || !equal(variables, this.lastWatch.variables)) {
                    this.cancel();
                    this.cancel = this.cache.watch(this.lastWatch = {
                        query: this.document,
                        variables: variables,
                        optimistic: true,
                        callback: function (diff) {
                            return _this.setDiff(diff);
                        }
                    });
                }
                return this;
            };
            QueryInfo.prototype.markResult = function (result, options, allowCacheWrite) {
                var _this = this;
                if (options.fetchPolicy === 'no-cache') {
                    this.diff = { result: result.data, complete: true };
                } else if (allowCacheWrite) {
                    var ignoreErrors = options.errorPolicy === 'ignore' || options.errorPolicy === 'all';
                    var writeWithErrors = !graphQLResultHasError(result);
                    if (!writeWithErrors && ignoreErrors && result.data) {
                        writeWithErrors = true;
                    }
                    if (writeWithErrors) {
                        this.cache.performTransaction(function (cache) {
                            cache.writeQuery({
                                query: _this.document,
                                data: result.data,
                                variables: options.variables
                            });
                            var diff = cache.diff({
                                query: _this.document,
                                variables: options.variables,
                                returnPartialData: true,
                                optimistic: true
                            });
                            _this.diff = diff;
                            if (diff.complete) {
                                result.data = diff.result;
                            }
                        });
                    }
                }
                this.graphQLErrors = isNonEmptyArray(result.errors) ? result.errors : [];
            };
            QueryInfo.prototype.markReady = function () {
                this.networkError = null;
                return this.networkStatus = NetworkStatus.ready;
            };
            QueryInfo.prototype.markError = function (error) {
                this.networkStatus = NetworkStatus.error;
                if (error.graphQLErrors) {
                    this.graphQLErrors = error.graphQLErrors;
                }
                if (error.networkError) {
                    this.networkError = error.networkError;
                }
                return error;
            };
            return QueryInfo;
        }();

        export { QueryInfo };
        //# sourceMappingURL=QueryInfo.js.map
    }
});
//# sourceMappingURL=QueryInfo.js.map