"use strict";

Liferay.Loader.define("questions-web$graphql@15.0.0/validation/rules/LoneAnonymousOperationRule", ['module', 'exports', 'require', '../../error/GraphQLError', '../../language/kinds'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.LoneAnonymousOperationRule = LoneAnonymousOperationRule;

    var _GraphQLError = require("../../error/GraphQLError");

    var _kinds = require("../../language/kinds");

    /**
     * Lone anonymous operation
     *
     * A GraphQL document is only valid if when it contains an anonymous operation
     * (the query short-hand) that it contains only that one operation definition.
     */
    function LoneAnonymousOperationRule(context) {
      var operationCount = 0;
      return {
        Document: function Document(node) {
          operationCount = node.definitions.filter(function (definition) {
            return definition.kind === _kinds.Kind.OPERATION_DEFINITION;
          }).length;
        },
        OperationDefinition: function OperationDefinition(node) {
          if (!node.name && operationCount > 1) {
            context.reportError(new _GraphQLError.GraphQLError('This anonymous operation must be the only defined operation.', node));
          }
        }
      };
    }
  }
});
//# sourceMappingURL=LoneAnonymousOperationRule.js.map